==> gossipcat-0.1.71-py3-none-any.whl: gossipcat/__version__.py <==
# 8b    d8 Yb  dP 88""Yb    db     dP""b8 88  dP    db     dP""b8 888888
# 88b  d88  YbdP  88__dP   dPYb   dP   `" 88odP    dPYb   dP   `" 88__
# 88YbdP88   8P   88"""   dP__Yb  Yb      88"Yb   dP__Yb  Yb  "88 88""
# 88 YY 88  dP    88     dP""""Yb  YboodP 88  Yb dP""""Yb  YboodP 888888

VERSION = (0, 1, 71)

__version__ = '.'.join(map(str, VERSION))

# python3 setup.py bdist_wheel
# twine upload dist/*

# pip3 install dist/my-project.whl


## PURPOSE

## The GossipCat is designed to build a high level tool kit for machine
## learning consulting. Its focus is not the algorithms but the application
## of them to industry.

## STRUCTURE

## I. 	Development Tool Kit
##			1. 	Configure
## 			2. 	Development
## 			3. 	Predict
##			4. 	Report

## II. 	Experiment Tool Kit
## 			1. 	Glimpse
##			2. 	Cluster
## 			3. 	Comparision
##			4. 	Baseline
##			5. 	Feature
## 			6. 	Similarity
##			7. 	Preprocess
##			8. 	SimAnneal
##			9. 	Tune
##			10.	Stack

## III. Graphic Tool Kit
## 			1. 	GraphicML

## DESIGN

## I.   Development Tool Kit ===============================
## Configure   =============================================
## 

## Development =============================================
## 

## II.  Experiment Tool Kit  ===============================
## Glimpse     =============================================
## Offering simple exploratory data analysis.

## Comparsion  =============================================
## 

## Baseline    =============================================
## Offering four basic machine learning algorithms as baseline:
## 1. Logistic regression
## 2. Random forest
## 3. Gradient boosting decision tree
## 4. Deep learning

## Cluster     =============================================
## 

## III. Graphic Tool Kit

==> gossipcat-0.1.72-py3-none-any.whl: gossipcat/__version__.py <==
# 8b    d8 Yb  dP 88""Yb    db     dP""b8 88  dP    db     dP""b8 888888
# 88b  d88  YbdP  88__dP   dPYb   dP   `" 88odP    dPYb   dP   `" 88__
# 88YbdP88   8P   88"""   dP__Yb  Yb      88"Yb   dP__Yb  Yb  "88 88""
# 88 YY 88  dP    88     dP""""Yb  YboodP 88  Yb dP""""Yb  YboodP 888888

VERSION = (0, 1, 72)

__version__ = '.'.join(map(str, VERSION))

# python3 setup.py bdist_wheel
# twine upload dist/*

# pip3 install dist/my-project.whl


## PURPOSE

## The GossipCat is designed to build a high level tool kit for machine
## learning consulting. Its focus is not the algorithms but the application
## of them to industry.

## STRUCTURE

## I.   Development Tool Kit
##          1.  Setup
##          2.  Configure
##          3.  Development
##          4.  Predict
##          5.  Report

## II.  Experiment Tool Kit
##          1.  Glimpse
##          2.  Cluster
##          3.  Comparision
##          4.  Baseline
##          5.  Feature
##          6.  Similarity
##          7.  Preprocess
##          8.  SimAnneal
##          9.  Tune
##          10. Stack

## III. Graphic Tool Kit
##          1.  GraphicML

## DESIGN

## I.   Development Tool Kit ===============================
##      1. Setup       =====================================
## Working as a shell script to establish a machine lerning
## file system.

##      2. Configure   =====================================
## Read configurations from config.json under the same directory.

##      3. Development =====================================
## 

## II.  Experiment Tool Kit  ===============================
## Glimpse     =============================================
## Offering simple exploratory data analysis.

## Comparsion  =============================================
## 

## Baseline    =============================================
## Offering four basic machine learning algorithms as baseline:
## 1. Logistic regression
## 2. Random forest
## 3. Gradient boosting decision tree
## 4. Deep learning

## Cluster     =============================================
## 

## III. Graphic Tool Kit
